@@ -43,11 +43,6 @@
 #include <gconf/gconf-client.h>
 #include <devkit-power-gobject/devicekit-power.h>
 
-#ifdef HAVE_POLKIT
-#include <polkit/polkit.h>
-#include <polkit-dbus/polkit-dbus.h>
-#endif
-
 #include "egg-debug.h"
 #include "egg-console-kit.h"
 
@@ -90,29 +85,6 @@ gpm_control_error_quark (void)
 	return quark;
 }
 
-/**
- * gpm_control_is_user_privileged:
- * @polkit: This polkit class instance
- * Return value: Success value.
- **/
-static gboolean
-gpm_control_is_user_privileged (GpmControl *control, const gchar *privilege)
-{
-	gboolean ret = TRUE;
-#ifdef HAVE_POLKIT
-	polkit_uint64_t mask;
-	pid_t pid;
-
-	pid = getpid ();
-	mask = polkit_check_auth (pid, privilege, NULL);
-	if (mask == 0) {
-		egg_warning ("failed to authorise for privilege %s", privilege);
-		ret = FALSE;
-	}
-#endif
-	return ret;
-}
-
 /**
  * gpm_control_check_foreground_console:
  * @manager: This class instance
@@ -158,19 +130,25 @@ gboolean
 gpm_control_allowed_suspend (GpmControl *control, gboolean *can, GError **error)
 {
 	gboolean conf_ok;
-	gboolean polkit_ok;
 	gboolean hardware_ok;
 	gboolean fg;
 	g_return_val_if_fail (can, FALSE);
 
 	*can = FALSE;
+
+	/* get values from DkpClient */
+	g_object_get (control->priv->client,
+		      "can-suspend", &hardware_ok,
+		      NULL);
+
 	conf_ok = gconf_client_get_bool (control->priv->conf, GPM_CONF_CAN_SUSPEND, NULL);
-	polkit_ok = gpm_control_is_user_privileged (control, "org.freedesktop.devicekit.power.suspend");
-	hardware_ok = dkp_client_can_suspend (control->priv->client);
+	g_object_get (control->priv->client,
+		      "can-suspend", &hardware_ok,
+		      NULL);
 	fg = gpm_control_check_foreground_console (control);
-	if (conf_ok && hardware_ok && polkit_ok && fg)
+	if (conf_ok && hardware_ok && fg)
 		*can = TRUE;
-	egg_debug ("conf=%i, polkit=%i, fg=%i, can=%i", conf_ok, polkit_ok, fg, *can);
+	egg_debug ("conf=%i, fg=%i, can=%i", conf_ok, fg, *can);
 	return TRUE;
 }
 
@@ -186,19 +164,24 @@ gboolean
 gpm_control_allowed_hibernate (GpmControl *control, gboolean *can, GError **error)
 {
 	gboolean conf_ok;
-	gboolean polkit_ok;
 	gboolean hardware_ok;
 	gboolean fg;
 	g_return_val_if_fail (can, FALSE);
 
+	/* get values from DkpClient */
+	g_object_get (control->priv->client,
+		      "can-hibernate", &hardware_ok,
+		      NULL);
+
 	*can = FALSE;
 	conf_ok = gconf_client_get_bool (control->priv->conf, GPM_CONF_CAN_HIBERNATE, NULL);
 	fg = gpm_control_check_foreground_console (control);
-	polkit_ok = gpm_control_is_user_privileged (control, "org.freedesktop.devicekit.power.hibernate");
-	hardware_ok = dkp_client_can_hibernate (control->priv->client);
-	if (conf_ok && hardware_ok && polkit_ok && fg)
+	g_object_get (control->priv->client,
+		      "can-hibernate", &hardware_ok,
+		      NULL);
+	if (conf_ok && hardware_ok && fg)
 		*can = TRUE;
-	egg_debug ("conf=%i, polkit=%i, fg=%i, can=%i", conf_ok, polkit_ok, fg, *can);
+	egg_debug ("conf=%i, fg=%i, can=%i", conf_ok, fg, *can);
 	return TRUE;
 }
 
