@@ -315,7 +315,7 @@ gpm_graph_widget_init (GpmGraphWidget *graph)
 	graph->priv->stop_y = 100;
 	graph->priv->use_grid = TRUE;
 	graph->priv->use_legend = FALSE;
-	graph->priv->data_list = g_ptr_array_new ();
+	graph->priv->data_list = g_ptr_array_new_with_free_func ((GDestroyNotify) g_ptr_array_unref);
 	graph->priv->plot_list = g_ptr_array_new ();
 	graph->priv->key_data = NULL;
 	graph->priv->type_x = GPM_GRAPH_WIDGET_TYPE_TIME;
@@ -338,17 +338,8 @@ gpm_graph_widget_init (GpmGraphWidget *graph)
 gboolean
 gpm_graph_widget_data_clear (GpmGraphWidget *graph)
 {
-	guint i;
-	GPtrArray *array;
-
 	g_return_val_if_fail (GPM_IS_GRAPH_WIDGET (graph), FALSE);
 
-	for (i=0; i<graph->priv->data_list->len; i++) {
-		array = g_ptr_array_index (graph->priv->data_list, i);
-		g_ptr_array_foreach (array, (GFunc) gpm_point_obj_free, NULL);
-		g_ptr_array_free (array, TRUE);
-	}
-
 	g_ptr_array_set_size (graph->priv->data_list, 0);
 	g_ptr_array_set_size (graph->priv->plot_list, 0);
 
@@ -370,8 +361,8 @@ gpm_graph_widget_finalize (GObject *object)
 	gpm_graph_widget_data_clear (graph);
 
 	/* free data */
-	g_ptr_array_free (graph->priv->data_list, TRUE);
-	g_ptr_array_free (graph->priv->plot_list, TRUE);
+	g_ptr_array_unref (graph->priv->data_list);
+	g_ptr_array_unref (graph->priv->plot_list);
 
 	context = pango_layout_get_context (graph->priv->layout);
 	g_object_unref (graph->priv->layout);
@@ -397,7 +388,7 @@ gpm_graph_widget_data_assign (GpmGraphWidget *graph, GpmGraphWidgetPlot plot, GP
 	g_return_val_if_fail (GPM_IS_GRAPH_WIDGET (graph), FALSE);
 
 	/* make a deep copy */
-	copy = g_ptr_array_new ();
+	copy = g_ptr_array_new_with_free_func ((GDestroyNotify) gpm_point_obj_free);
 	for (i=0; i<data->len; i++) {
 		obj = gpm_point_obj_copy (g_ptr_array_index (data, i));
 		g_ptr_array_add (copy, obj);
@@ -1082,6 +1073,7 @@ gpm_graph_widget_legend_calculate_size (GpmGraphWidget *graph, cairo_t *cr,
 static void
 gpm_graph_widget_draw_graph (GtkWidget *graph_widget, cairo_t *cr)
 {
+	GtkAllocation allocation;
 	gint legend_x = 0;
 	gint legend_y = 0;
 	guint legend_height = 0;
@@ -1105,16 +1097,17 @@ gpm_graph_widget_draw_graph (GtkWidget *graph_widget, cairo_t *cr)
 	graph->priv->box_x = gpm_graph_widget_get_y_label_max_width (graph, cr) + 10;
 	graph->priv->box_y = 5;
 
-	graph->priv->box_height = graph_widget->allocation.height - (20 + graph->priv->box_y);
+	gtk_widget_get_allocation (graph_widget, &allocation);
+	graph->priv->box_height = allocation.height - (20 + graph->priv->box_y);
 
 	/* make size adjustment for legend */
 	if (graph->priv->use_legend && legend_height > 0) {
-		graph->priv->box_width = graph_widget->allocation.width -
+		graph->priv->box_width = allocation.width -
 					 (3 + legend_width + 5 + graph->priv->box_x);
 		legend_x = graph->priv->box_x + graph->priv->box_width + 6;
 		legend_y = graph->priv->box_y;
 	} else {
-		graph->priv->box_width = graph_widget->allocation.width -
+		graph->priv->box_width = allocation.width -
 					 (3 + graph->priv->box_x);
 	}
 
@@ -1152,7 +1145,7 @@ gpm_graph_widget_expose (GtkWidget *graph, GdkEventExpose *event)
 	cairo_t *cr;
 
 	/* get a cairo_t */
-	cr = gdk_cairo_create (graph->window);
+	cr = gdk_cairo_create (gtk_widget_get_window (graph));
 	cairo_rectangle (cr,
 			 event->area.x, event->area.y,
 			 event->area.width, event->area.height);
