@@ -54,7 +54,6 @@
 #include "gpm-manager.h"
 #include "gpm-screensaver.h"
 #include "gpm-backlight.h"
-#include "gpm-screensaver.h"
 #include "gpm-session.h"
 #include "gpm-stock-icons.h"
 #include "gpm-prefs-server.h"
@@ -955,6 +954,7 @@ gpm_manager_tray_icon_suspend (GpmManager *manager, GpmTrayIcon *tray)
 	gpm_manager_action_suspend (manager, "User clicked on tray");
 }
 
+#if 0
 /**
  * gpm_manager_screensaver_auth_request_cb:
  * @manager: This manager class instance
@@ -979,6 +979,7 @@ gpm_manager_screensaver_auth_request_cb (GpmScreensaver *screensaver, gboolean a
 		}
 	}
 }
+#endif
 
 /**
  * gpm_manager_perhaps_recall_response_cb:
@@ -1358,7 +1359,7 @@ gpm_manager_engine_just_laptop_battery (GpmManager *manager)
 {
 	DkpDevice *device;
 	DkpDeviceType type;
-	const GPtrArray *array;
+	GPtrArray *array;
 	gboolean ret = TRUE;
 	guint i;
 
@@ -1373,7 +1374,7 @@ gpm_manager_engine_just_laptop_battery (GpmManager *manager)
 			break;
 		}
 	}
-
+	g_ptr_array_unref (array);
 	return ret;
 }
 
@@ -1866,8 +1867,10 @@ gpm_manager_init (GpmManager *manager)
 
 	/* try and start an interactive service */
 	manager->priv->screensaver = gpm_screensaver_new ();
+#if 0
 	g_signal_connect (manager->priv->screensaver, "auth-request",
 			  G_CALLBACK (gpm_manager_screensaver_auth_request_cb), manager);
+#endif
 
 	/* try an start an interactive service */
 	manager->priv->backlight = gpm_backlight_new ();
