@@ -37,7 +37,7 @@ static void     gpm_screensaver_finalize   (GObject		*object);
 #define GPM_SCREENSAVER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_SCREENSAVER, GpmScreensaverPrivate))
 
 #define GS_LISTENER_SERVICE	"org.gnome.ScreenSaver"
-#define GS_LISTENER_PATH	"/org/gnome/ScreenSaver"
+#define GS_LISTENER_PATH	"/"
 #define GS_LISTENER_INTERFACE	"org.gnome.ScreenSaver"
 
 struct GpmScreensaverPrivate
@@ -47,17 +47,19 @@ struct GpmScreensaverPrivate
 };
 
 enum {
-	GS_DELAY_CHANGED,
-	CONNECTION_CHANGED,
 	AUTH_REQUEST,
 	LAST_SIGNAL
 };
 
+#if 0
 static guint signals [LAST_SIGNAL] = { 0 };
+#endif
 static gpointer gpm_screensaver_object = NULL;
 
 G_DEFINE_TYPE (GpmScreensaver, gpm_screensaver, G_TYPE_OBJECT)
 
+#if 0
+
 /** Invoked when we get the AuthenticationRequestBegin from g-s when the user
  *  has moved their mouse and we are showing the authentication box.
  */
@@ -97,8 +99,6 @@ gpm_screensaver_proxy_connect_more (GpmScreensaver *screensaver)
 		return FALSE;
 	}
 
-	g_signal_emit (screensaver, signals [CONNECTION_CHANGED], 0, TRUE);
-
 	/* get AuthenticationRequestBegin */
 	dbus_g_proxy_add_signal (proxy, "AuthenticationRequestBegin", G_TYPE_INVALID);
 	dbus_g_proxy_connect_signal (proxy,
@@ -124,11 +124,10 @@ static gboolean
 gpm_screensaver_proxy_disconnect_more (GpmScreensaver *screensaver)
 {
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
-
-	g_signal_emit (screensaver, signals [CONNECTION_CHANGED], 0, FALSE);
 	egg_debug ("gnome-screensaver disconnected from the session DBUS");
 	return TRUE;
 }
+#endif
 
 /**
  * gpm_screensaver_lock_enabled:
@@ -140,25 +139,10 @@ gpm_screensaver_lock_enabled (GpmScreensaver *screensaver)
 {
 	gboolean enabled;
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
-
 	enabled = gconf_client_get_bool (screensaver->priv->conf, GS_PREF_LOCK_ENABLED, NULL);
-
 	return enabled;
 }
 
-/**
- * gpm_screensaver_lock_set:
- * @screensaver: This class instance
- * @lock: If gnome-screensaver should lock the screen on screensave
- **/
-gboolean
-gpm_screensaver_lock_set (GpmScreensaver *screensaver, gboolean lock)
-{
-	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
-	gconf_client_set_bool (screensaver->priv->conf, GS_PREF_LOCK_ENABLED, lock, NULL);
-	return TRUE;
-}
-
 /**
  * gpm_screensaver_lock
  * @screensaver: This class instance
@@ -250,9 +234,11 @@ gpm_screensaver_add_throttle (GpmScreensaver *screensaver,
 	return cookie;
 }
 
+/**
+ * gpm_screensaver_remove_throttle:
+ **/
 gboolean
-gpm_screensaver_remove_throttle (GpmScreensaver *screensaver,
-				 guint           cookie)
+gpm_screensaver_remove_throttle (GpmScreensaver *screensaver, guint cookie)
 {
 	gboolean ret;
 	DBusGProxy *proxy;
@@ -356,26 +342,7 @@ gpm_screensaver_class_init (GpmScreensaverClass *klass)
 	object_class->finalize = gpm_screensaver_finalize;
 	g_type_class_add_private (klass, sizeof (GpmScreensaverPrivate));
 
-	signals [GS_DELAY_CHANGED] =
-		g_signal_new ("gs-delay-changed",
-			      G_TYPE_FROM_CLASS (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GpmScreensaverClass, gs_delay_changed),
-			      NULL,
-			      NULL,
-			      g_cclosure_marshal_VOID__INT,
-			      G_TYPE_NONE, 1, G_TYPE_INT);
-
-	signals [CONNECTION_CHANGED] =
-		g_signal_new ("connection-changed",
-			      G_TYPE_FROM_CLASS (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GpmScreensaverClass, connection_changed),
-			      NULL,
-			      NULL,
-			      g_cclosure_marshal_VOID__BOOLEAN,
-			      G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
-
+#if 0
 	signals [AUTH_REQUEST] =
 		g_signal_new ("auth-request",
 			      G_TYPE_FROM_CLASS (object_class),
@@ -385,26 +352,27 @@ gpm_screensaver_class_init (GpmScreensaverClass *klass)
 			      NULL,
 			      g_cclosure_marshal_VOID__BOOLEAN,
 			      G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
+#endif
 }
 
 /**
- * proxy_status_cb:
+ * gpm_screensaver_proxy_status_cb:
  * @proxy: The dbus raw proxy
  * @status: The status of the service, where TRUE is connected
  * @screensaver: This class instance
  **/
 static void
-proxy_status_cb (DBusGProxy     *proxy,
-		 gboolean	 status,
-		 GpmScreensaver *screensaver)
+gpm_screensaver_proxy_status_cb (DBusGProxy *proxy, gboolean status, GpmScreensaver *screensaver)
 {
 	g_return_if_fail (GPM_IS_SCREENSAVER (screensaver));
 
+#if 0
 	if (status) {
 		gpm_screensaver_proxy_connect_more (screensaver);
 	} else {
 		gpm_screensaver_proxy_disconnect_more (screensaver);
 	}
+#endif
 }
 
 /**
@@ -425,10 +393,12 @@ gpm_screensaver_init (GpmScreensaver *screensaver)
 				       GS_LISTENER_PATH, GS_LISTENER_INTERFACE);
 
 	g_signal_connect (screensaver->priv->gproxy, "proxy-status",
-			  G_CALLBACK (proxy_status_cb),
+			  G_CALLBACK (gpm_screensaver_proxy_status_cb),
 			  screensaver);
-
-	gpm_screensaver_proxy_connect_more (screensaver);
+#if 0
+	if (proxy != NULL)
+		gpm_screensaver_proxy_connect_more (screensaver);
+#endif
 
 	screensaver->priv->conf = gconf_client_get_default ();
 }
@@ -447,7 +417,9 @@ gpm_screensaver_finalize (GObject *object)
 	screensaver = GPM_SCREENSAVER (object);
 	screensaver->priv = GPM_SCREENSAVER_GET_PRIVATE (screensaver);
 
+#if 0
 	gpm_screensaver_proxy_disconnect_more (screensaver);
+#endif
 	g_object_unref (screensaver->priv->conf);
 	g_object_unref (screensaver->priv->gproxy);
 
@@ -469,3 +441,59 @@ gpm_screensaver_new (void)
 	}
 	return GPM_SCREENSAVER (gpm_screensaver_object);
 }
+/***************************************************************************
+ ***                          MAKE CHECK TESTS                           ***
+ ***************************************************************************/
+#ifdef EGG_TEST
+#include "egg-test.h"
+
+#if 0
+static gboolean test_got_request = FALSE;
+static void
+gpm_screensaver_test_auth_request_cb (GpmScreensaver *screensaver, gboolean auth, EggTest *test)
+{
+	egg_debug ("auth request = %i", auth);
+	test_got_request = auth;
+
+	egg_test_loop_quit (test);
+}
+#endif
+
+void
+gpm_screensaver_test (gpointer data)
+{
+	GpmScreensaver *screensaver;
+//	guint value;
+	gboolean ret;
+	EggTest *test = (EggTest *) data;
+
+	if (egg_test_start (test, "GpmScreensaver") == FALSE)
+		return;
+
+	/************************************************************/
+	egg_test_title (test, "make sure we get a non null screensaver");
+	screensaver = gpm_screensaver_new ();
+	egg_test_assert (test, (screensaver != NULL));
+
+#if 0
+	/* connect signals */
+	g_signal_connect (screensaver, "auth-request",
+			  G_CALLBACK (gpm_screensaver_test_auth_request_cb), test);
+#endif
+	/************************************************************/
+	egg_test_title (test, "lock screensaver");
+	ret = gpm_screensaver_lock (screensaver);
+	egg_test_assert (test, ret);
+
+	/************************************************************/
+	egg_test_title (test, "poke screensaver");
+	ret = gpm_screensaver_poke (screensaver);
+	egg_test_assert (test, ret);
+
+	g_object_unref (screensaver);
+
+	egg_test_end (test);
+}
+
+#endif
+
